============
katcp-python
============

|Doc Status|
|PyPI Version|
|Python Versions|

Python client and server library for the Karoo Array Telescope Control Protocol
(KATCP).  For more info, see the doc directory in this repository, or for online
documentation of the latest release, `read the katcp-python documentation
<http://katcp-python.readthedocs.io/en/latest/>`_.

.. |Doc Status| image:: https://readthedocs.org/projects/katcp-python/badge/?version=latest
                :target: http://katcp-python.readthedocs.io/en/latest
                :alt:

.. |PyPI Version| image:: https://img.shields.io/pypi/v/katcp.svg
                  :target: https://pypi.python.org/pypi/katcp
                  :alt:

.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/katcp.svg
                     :target: https://pypi.python.org/pypi/katcp/
                     :alt:
